pub struct PreparedStatementCache { /* private fields */ }Expand description
A cache for prepared statements.
This cache stores prepared statements by their SQL query string, allowing reuse of statements across multiple queries.
Implementations
Sourceimpl PreparedStatementCache
impl PreparedStatementCache
Sourcepub async fn get_or_prepare(
&self,
client: &Object,
sql: &str,
) -> PgResult<Statement>
pub async fn get_or_prepare( &self, client: &Object, sql: &str, ) -> PgResult<Statement>
Get or prepare a statement for the given SQL.
Sourcepub async fn get_or_prepare_in_txn<'a>(
&self,
txn: &Transaction<'a>,
sql: &str,
) -> PgResult<Statement>
pub async fn get_or_prepare_in_txn<'a>( &self, txn: &Transaction<'a>, sql: &str, ) -> PgResult<Statement>
Get or prepare a statement within a transaction.